# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.models.stored_value_response import StoredValueResponse  # noqa: E501
from pycherwell.rest import ApiException


class TestStoredValueResponse(unittest.TestCase):
    """StoredValueResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStoredValueResponse(self):
        """Test StoredValueResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = pycherwell.models.stored_value_response.StoredValueResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.users_api import UsersApi  # noqa: E501
from pycherwell.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.users_api.UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_users_delete_user_batch_v1(self):
        """Test case for users_delete_user_batch_v1

        Delete a batch of users  # noqa: E501
        """
        pass

    def test_users_delete_user_batch_v2(self):
        """Test case for users_delete_user_batch_v2

        Delete a batch of users  # noqa: E501
        """
        pass

    def test_users_delete_user_v1(self):
        """Test case for users_delete_user_v1

        Delete a user by record ID  # noqa: E501
        """
        pass

    def test_users_delete_user_v2(self):
        """Test case for users_delete_user_v2

        Delete a user by record ID  # noqa: E501
        """
        pass

    def test_users_get_list_of_users(self):
        """Test case for users_get_list_of_users

        Get a list of all system users.  # noqa: E501
        """
        pass

    def test_users_get_user_batch_v1(self):
        """Test case for users_get_user_batch_v1

        Get user information in a batch  # noqa: E501
        """
        pass

    def test_users_get_user_by_login_id_v1(self):
        """Test case for users_get_user_by_login_id_v1

        Get a user by login ID  # noqa: E501
        """
        pass

    def test_users_get_user_by_login_id_v2(self):
        """Test case for users_get_user_by_login_id_v2

        Get a user by login ID and login ID type  # noqa: E501
        """
        pass

    def test_users_get_user_by_login_id_v3(self):
        """Test case for users_get_user_by_login_id_v3

        Get a user by login ID and login ID type  # noqa: E501
        """
        pass

    def test_users_get_user_by_public_id_v1(self):
        """Test case for users_get_user_by_public_id_v1

        Get a user by public ID  # noqa: E501
        """
        pass

    def test_users_get_user_by_public_id_v2(self):
        """Test case for users_get_user_by_public_id_v2

        Get a user by public ID  # noqa: E501
        """
        pass

    def test_users_get_user_by_rec_id(self):
        """Test case for users_get_user_by_rec_id

        Get a user by record ID  # noqa: E501
        """
        pass

    def test_users_save_user_batch_v1(self):
        """Test case for users_save_user_batch_v1

        Create or update users in a batch  # noqa: E501
        """
        pass

    def test_users_save_user_batch_v2(self):
        """Test case for users_save_user_batch_v2

        Create or update users in a batch  # noqa: E501
        """
        pass

    def test_users_save_user_v1(self):
        """Test case for users_save_user_v1

        Create or update a user  # noqa: E501
        """
        pass

    def test_users_save_user_v2(self):
        """Test case for users_save_user_v2

        Create or update a user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class QuickSearchItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ascending': 'bool',
        'changed_limits': 'list[ChangedLimit]',
        'changed_option': 'str',
        'display_name': 'str',
        'gallery_image': 'str',
        'has_any_options': 'bool',
        'non_final_state_option': 'str',
        'search_any_words_option': 'str',
        'search_attachments_option': 'str',
        'search_related_option': 'str',
        'search_target_id': 'str',
        'search_target_type': 'str',
        'selected_changed_limit': 'ChangedLimit',
        'selected_sort_by_field_id': 'str',
        'sort_by_fields': 'list[KeyValuePairStringString]',
        'sort_by_option': 'str',
        'watermark_text': 'str'
    }

    attribute_map = {
        'ascending': 'ascending',
        'changed_limits': 'changedLimits',
        'changed_option': 'changedOption',
        'display_name': 'displayName',
        'gallery_image': 'galleryImage',
        'has_any_options': 'hasAnyOptions',
        'non_final_state_option': 'nonFinalStateOption',
        'search_any_words_option': 'searchAnyWordsOption',
        'search_attachments_option': 'searchAttachmentsOption',
        'search_related_option': 'searchRelatedOption',
        'search_target_id': 'searchTargetId',
        'search_target_type': 'searchTargetType',
        'selected_changed_limit': 'selectedChangedLimit',
        'selected_sort_by_field_id': 'selectedSortByFieldId',
        'sort_by_fields': 'sortByFields',
        'sort_by_option': 'sortByOption',
        'watermark_text': 'watermarkText'
    }

    def __init__(self, ascending=None, changed_limits=None, changed_option=None, display_name=None, gallery_image=None, has_any_options=None, non_final_state_option=None, search_any_words_option=None, search_attachments_option=None, search_related_option=None, search_target_id=None, search_target_type=None, selected_changed_limit=None, selected_sort_by_field_id=None, sort_by_fields=None, sort_by_option=None, watermark_text=None, local_vars_configuration=None):  # noqa: E501
        """QuickSearchItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ascending = None
        self._changed_limits = None
        self._changed_option = None
        self._display_name = None
        self._gallery_image = None
        self._has_any_options = None
        self._non_final_state_option = None
        self._search_any_words_option = None
        self._search_attachments_option = None
        self._search_related_option = None
        self._search_target_id = None
        self._search_target_type = None
        self._selected_changed_limit = None
        self._selected_sort_by_field_id = None
        self._sort_by_fields = None
        self._sort_by_option = None
        self._watermark_text = None
        self.discriminator = None

        if ascending is not None:
            self.ascending = ascending
        if changed_limits is not None:
            self.changed_limits = changed_limits
        if changed_option is not None:
            self.changed_option = changed_option
        if display_name is not None:
            self.display_name = display_name
        if gallery_image is not None:
            self.gallery_image = gallery_image
        if has_any_options is not None:
            self.has_any_options = has_any_options
        if non_final_state_option is not None:
            self.non_final_state_option = non_final_state_option
        if search_any_words_option is not None:
            self.search_any_words_option = search_any_words_option
        if search_attachments_option is not None:
            self.search_attachments_option = search_attachments_option
        if search_related_option is not None:
            self.search_related_option = search_related_option
        if search_target_id is not None:
            self.search_target_id = search_target_id
        if search_target_type is not None:
            self.search_target_type = search_target_type
        if selected_changed_limit is not None:
            self.selected_changed_limit = selected_changed_limit
        if selected_sort_by_field_id is not None:
            self.selected_sort_by_field_id = selected_sort_by_field_id
        if sort_by_fields is not None:
            self.sort_by_fields = sort_by_fields
        if sort_by_option is not None:
            self.sort_by_option = sort_by_option
        if watermark_text is not None:
            self.watermark_text = watermark_text

    @property
    def ascending(self):
        """Gets the ascending of this QuickSearchItem.  # noqa: E501


        :return: The ascending of this QuickSearchItem.  # noqa: E501
        :rtype: bool
        """
        return self._ascending

    @ascending.setter
    def ascending(self, ascending):
        """Sets the ascending of this QuickSearchItem.


        :param ascending: The ascending of this QuickSearchItem.  # noqa: E501
        :type: bool
        """

        self._ascending = ascending

    @property
    def changed_limits(self):
        """Gets the changed_limits of this QuickSearchItem.  # noqa: E501


        :return: The changed_limits of this QuickSearchItem.  # noqa: E501
        :rtype: list[ChangedLimit]
        """
        return self._changed_limits

    @changed_limits.setter
    def changed_limits(self, changed_limits):
        """Sets the changed_limits of this QuickSearchItem.


        :param changed_limits: The changed_limits of this QuickSearchItem.  # noqa: E501
        :type: list[ChangedLimit]
        """

        self._changed_limits = changed_limits

    @property
    def changed_option(self):
        """Gets the changed_option of this QuickSearchItem.  # noqa: E501


        :return: The changed_option of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._changed_option

    @changed_option.setter
    def changed_option(self, changed_option):
        """Sets the changed_option of this QuickSearchItem.


        :param changed_option: The changed_option of this QuickSearchItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Use", "Display", "UseAndDisplay"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and changed_option not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `changed_option` ({0}), must be one of {1}"  # noqa: E501
                .format(changed_option, allowed_values)
            )

        self._changed_option = changed_option

    @property
    def display_name(self):
        """Gets the display_name of this QuickSearchItem.  # noqa: E501


        :return: The display_name of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this QuickSearchItem.


        :param display_name: The display_name of this QuickSearchItem.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def gallery_image(self):
        """Gets the gallery_image of this QuickSearchItem.  # noqa: E501


        :return: The gallery_image of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._gallery_image

    @gallery_image.setter
    def gallery_image(self, gallery_image):
        """Sets the gallery_image of this QuickSearchItem.


        :param gallery_image: The gallery_image of this QuickSearchItem.  # noqa: E501
        :type: str
        """

        self._gallery_image = gallery_image

    @property
    def has_any_options(self):
        """Gets the has_any_options of this QuickSearchItem.  # noqa: E501


        :return: The has_any_options of this QuickSearchItem.  # noqa: E501
        :rtype: bool
        """
        return self._has_any_options

    @has_any_options.setter
    def has_any_options(self, has_any_options):
        """Sets the has_any_options of this QuickSearchItem.


        :param has_any_options: The has_any_options of this QuickSearchItem.  # noqa: E501
        :type: bool
        """

        self._has_any_options = has_any_options

    @property
    def non_final_state_option(self):
        """Gets the non_final_state_option of this QuickSearchItem.  # noqa: E501


        :return: The non_final_state_option of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._non_final_state_option

    @non_final_state_option.setter
    def non_final_state_option(self, non_final_state_option):
        """Sets the non_final_state_option of this QuickSearchItem.


        :param non_final_state_option: The non_final_state_option of this QuickSearchItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Use", "Display", "UseAndDisplay"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and non_final_state_option not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `non_final_state_option` ({0}), must be one of {1}"  # noqa: E501
                .format(non_final_state_option, allowed_values)
            )

        self._non_final_state_option = non_final_state_option

    @property
    def search_any_words_option(self):
        """Gets the search_any_words_option of this QuickSearchItem.  # noqa: E501


        :return: The search_any_words_option of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._search_any_words_option

    @search_any_words_option.setter
    def search_any_words_option(self, search_any_words_option):
        """Sets the search_any_words_option of this QuickSearchItem.


        :param search_any_words_option: The search_any_words_option of this QuickSearchItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Use", "Display", "UseAndDisplay"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and search_any_words_option not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `search_any_words_option` ({0}), must be one of {1}"  # noqa: E501
                .format(search_any_words_option, allowed_values)
            )

        self._search_any_words_option = search_any_words_option

    @property
    def search_attachments_option(self):
        """Gets the search_attachments_option of this QuickSearchItem.  # noqa: E501


        :return: The search_attachments_option of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._search_attachments_option

    @search_attachments_option.setter
    def search_attachments_option(self, search_attachments_option):
        """Sets the search_attachments_option of this QuickSearchItem.


        :param search_attachments_option: The search_attachments_option of this QuickSearchItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Use", "Display", "UseAndDisplay"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and search_attachments_option not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `search_attachments_option` ({0}), must be one of {1}"  # noqa: E501
                .format(search_attachments_option, allowed_values)
            )

        self._search_attachments_option = search_attachments_option

    @property
    def search_related_option(self):
        """Gets the search_related_option of this QuickSearchItem.  # noqa: E501


        :return: The search_related_option of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._search_related_option

    @search_related_option.setter
    def search_related_option(self, search_related_option):
        """Sets the search_related_option of this QuickSearchItem.


        :param search_related_option: The search_related_option of this QuickSearchItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Use", "Display", "UseAndDisplay"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and search_related_option not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `search_related_option` ({0}), must be one of {1}"  # noqa: E501
                .format(search_related_option, allowed_values)
            )

        self._search_related_option = search_related_option

    @property
    def search_target_id(self):
        """Gets the search_target_id of this QuickSearchItem.  # noqa: E501


        :return: The search_target_id of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._search_target_id

    @search_target_id.setter
    def search_target_id(self, search_target_id):
        """Sets the search_target_id of this QuickSearchItem.


        :param search_target_id: The search_target_id of this QuickSearchItem.  # noqa: E501
        :type: str
        """

        self._search_target_id = search_target_id

    @property
    def search_target_type(self):
        """Gets the search_target_type of this QuickSearchItem.  # noqa: E501


        :return: The search_target_type of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._search_target_type

    @search_target_type.setter
    def search_target_type(self, search_target_type):
        """Sets the search_target_type of this QuickSearchItem.


        :param search_target_type: The search_target_type of this QuickSearchItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["BusOb", "DocRepository"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and search_target_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `search_target_type` ({0}), must be one of {1}"  # noqa: E501
                .format(search_target_type, allowed_values)
            )

        self._search_target_type = search_target_type

    @property
    def selected_changed_limit(self):
        """Gets the selected_changed_limit of this QuickSearchItem.  # noqa: E501


        :return: The selected_changed_limit of this QuickSearchItem.  # noqa: E501
        :rtype: ChangedLimit
        """
        return self._selected_changed_limit

    @selected_changed_limit.setter
    def selected_changed_limit(self, selected_changed_limit):
        """Sets the selected_changed_limit of this QuickSearchItem.


        :param selected_changed_limit: The selected_changed_limit of this QuickSearchItem.  # noqa: E501
        :type: ChangedLimit
        """

        self._selected_changed_limit = selected_changed_limit

    @property
    def selected_sort_by_field_id(self):
        """Gets the selected_sort_by_field_id of this QuickSearchItem.  # noqa: E501


        :return: The selected_sort_by_field_id of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._selected_sort_by_field_id

    @selected_sort_by_field_id.setter
    def selected_sort_by_field_id(self, selected_sort_by_field_id):
        """Sets the selected_sort_by_field_id of this QuickSearchItem.


        :param selected_sort_by_field_id: The selected_sort_by_field_id of this QuickSearchItem.  # noqa: E501
        :type: str
        """

        self._selected_sort_by_field_id = selected_sort_by_field_id

    @property
    def sort_by_fields(self):
        """Gets the sort_by_fields of this QuickSearchItem.  # noqa: E501


        :return: The sort_by_fields of this QuickSearchItem.  # noqa: E501
        :rtype: list[KeyValuePairStringString]
        """
        return self._sort_by_fields

    @sort_by_fields.setter
    def sort_by_fields(self, sort_by_fields):
        """Sets the sort_by_fields of this QuickSearchItem.


        :param sort_by_fields: The sort_by_fields of this QuickSearchItem.  # noqa: E501
        :type: list[KeyValuePairStringString]
        """

        self._sort_by_fields = sort_by_fields

    @property
    def sort_by_option(self):
        """Gets the sort_by_option of this QuickSearchItem.  # noqa: E501


        :return: The sort_by_option of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._sort_by_option

    @sort_by_option.setter
    def sort_by_option(self, sort_by_option):
        """Sets the sort_by_option of this QuickSearchItem.


        :param sort_by_option: The sort_by_option of this QuickSearchItem.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Use", "Display", "UseAndDisplay"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and sort_by_option not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `sort_by_option` ({0}), must be one of {1}"  # noqa: E501
                .format(sort_by_option, allowed_values)
            )

        self._sort_by_option = sort_by_option

    @property
    def watermark_text(self):
        """Gets the watermark_text of this QuickSearchItem.  # noqa: E501


        :return: The watermark_text of this QuickSearchItem.  # noqa: E501
        :rtype: str
        """
        return self._watermark_text

    @watermark_text.setter
    def watermark_text(self, watermark_text):
        """Sets the watermark_text of this QuickSearchItem.


        :param watermark_text: The watermark_text of this QuickSearchItem.  # noqa: E501
        :type: str
        """

        self._watermark_text = watermark_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuickSearchItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QuickSearchItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class BusinessObjectPermission(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bus_ob_id': 'str',
        'bus_ob_name': 'str',
        'department_member_edit': 'bool',
        'department_member_view': 'bool',
        'edit': 'bool',
        'field_permissions': 'list[FieldPermission]',
        'manager_of_owner_edit': 'bool',
        'manager_of_owner_view': 'bool',
        'owner_edit': 'bool',
        'owner_view': 'bool',
        'team_edit': 'bool',
        'team_manager_of_owner_edit': 'bool',
        'team_manager_of_owner_view': 'bool',
        'team_view': 'bool',
        'view': 'bool'
    }

    attribute_map = {
        'bus_ob_id': 'busObId',
        'bus_ob_name': 'busObName',
        'department_member_edit': 'departmentMemberEdit',
        'department_member_view': 'departmentMemberView',
        'edit': 'edit',
        'field_permissions': 'fieldPermissions',
        'manager_of_owner_edit': 'managerOfOwnerEdit',
        'manager_of_owner_view': 'managerOfOwnerView',
        'owner_edit': 'ownerEdit',
        'owner_view': 'ownerView',
        'team_edit': 'teamEdit',
        'team_manager_of_owner_edit': 'teamManagerOfOwnerEdit',
        'team_manager_of_owner_view': 'teamManagerOfOwnerView',
        'team_view': 'teamView',
        'view': 'view'
    }

    def __init__(self, bus_ob_id=None, bus_ob_name=None, department_member_edit=None, department_member_view=None, edit=None, field_permissions=None, manager_of_owner_edit=None, manager_of_owner_view=None, owner_edit=None, owner_view=None, team_edit=None, team_manager_of_owner_edit=None, team_manager_of_owner_view=None, team_view=None, view=None, local_vars_configuration=None):  # noqa: E501
        """BusinessObjectPermission - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bus_ob_id = None
        self._bus_ob_name = None
        self._department_member_edit = None
        self._department_member_view = None
        self._edit = None
        self._field_permissions = None
        self._manager_of_owner_edit = None
        self._manager_of_owner_view = None
        self._owner_edit = None
        self._owner_view = None
        self._team_edit = None
        self._team_manager_of_owner_edit = None
        self._team_manager_of_owner_view = None
        self._team_view = None
        self._view = None
        self.discriminator = None

        if bus_ob_id is not None:
            self.bus_ob_id = bus_ob_id
        if bus_ob_name is not None:
            self.bus_ob_name = bus_ob_name
        if department_member_edit is not None:
            self.department_member_edit = department_member_edit
        if department_member_view is not None:
            self.department_member_view = department_member_view
        if edit is not None:
            self.edit = edit
        if field_permissions is not None:
            self.field_permissions = field_permissions
        if manager_of_owner_edit is not None:
            self.manager_of_owner_edit = manager_of_owner_edit
        if manager_of_owner_view is not None:
            self.manager_of_owner_view = manager_of_owner_view
        if owner_edit is not None:
            self.owner_edit = owner_edit
        if owner_view is not None:
            self.owner_view = owner_view
        if team_edit is not None:
            self.team_edit = team_edit
        if team_manager_of_owner_edit is not None:
            self.team_manager_of_owner_edit = team_manager_of_owner_edit
        if team_manager_of_owner_view is not None:
            self.team_manager_of_owner_view = team_manager_of_owner_view
        if team_view is not None:
            self.team_view = team_view
        if view is not None:
            self.view = view

    @property
    def bus_ob_id(self):
        """Gets the bus_ob_id of this BusinessObjectPermission.  # noqa: E501


        :return: The bus_ob_id of this BusinessObjectPermission.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_id

    @bus_ob_id.setter
    def bus_ob_id(self, bus_ob_id):
        """Sets the bus_ob_id of this BusinessObjectPermission.


        :param bus_ob_id: The bus_ob_id of this BusinessObjectPermission.  # noqa: E501
        :type: str
        """

        self._bus_ob_id = bus_ob_id

    @property
    def bus_ob_name(self):
        """Gets the bus_ob_name of this BusinessObjectPermission.  # noqa: E501


        :return: The bus_ob_name of this BusinessObjectPermission.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_name

    @bus_ob_name.setter
    def bus_ob_name(self, bus_ob_name):
        """Sets the bus_ob_name of this BusinessObjectPermission.


        :param bus_ob_name: The bus_ob_name of this BusinessObjectPermission.  # noqa: E501
        :type: str
        """

        self._bus_ob_name = bus_ob_name

    @property
    def department_member_edit(self):
        """Gets the department_member_edit of this BusinessObjectPermission.  # noqa: E501


        :return: The department_member_edit of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._department_member_edit

    @department_member_edit.setter
    def department_member_edit(self, department_member_edit):
        """Sets the department_member_edit of this BusinessObjectPermission.


        :param department_member_edit: The department_member_edit of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._department_member_edit = department_member_edit

    @property
    def department_member_view(self):
        """Gets the department_member_view of this BusinessObjectPermission.  # noqa: E501


        :return: The department_member_view of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._department_member_view

    @department_member_view.setter
    def department_member_view(self, department_member_view):
        """Sets the department_member_view of this BusinessObjectPermission.


        :param department_member_view: The department_member_view of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._department_member_view = department_member_view

    @property
    def edit(self):
        """Gets the edit of this BusinessObjectPermission.  # noqa: E501


        :return: The edit of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._edit

    @edit.setter
    def edit(self, edit):
        """Sets the edit of this BusinessObjectPermission.


        :param edit: The edit of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._edit = edit

    @property
    def field_permissions(self):
        """Gets the field_permissions of this BusinessObjectPermission.  # noqa: E501


        :return: The field_permissions of this BusinessObjectPermission.  # noqa: E501
        :rtype: list[FieldPermission]
        """
        return self._field_permissions

    @field_permissions.setter
    def field_permissions(self, field_permissions):
        """Sets the field_permissions of this BusinessObjectPermission.


        :param field_permissions: The field_permissions of this BusinessObjectPermission.  # noqa: E501
        :type: list[FieldPermission]
        """

        self._field_permissions = field_permissions

    @property
    def manager_of_owner_edit(self):
        """Gets the manager_of_owner_edit of this BusinessObjectPermission.  # noqa: E501


        :return: The manager_of_owner_edit of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._manager_of_owner_edit

    @manager_of_owner_edit.setter
    def manager_of_owner_edit(self, manager_of_owner_edit):
        """Sets the manager_of_owner_edit of this BusinessObjectPermission.


        :param manager_of_owner_edit: The manager_of_owner_edit of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._manager_of_owner_edit = manager_of_owner_edit

    @property
    def manager_of_owner_view(self):
        """Gets the manager_of_owner_view of this BusinessObjectPermission.  # noqa: E501


        :return: The manager_of_owner_view of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._manager_of_owner_view

    @manager_of_owner_view.setter
    def manager_of_owner_view(self, manager_of_owner_view):
        """Sets the manager_of_owner_view of this BusinessObjectPermission.


        :param manager_of_owner_view: The manager_of_owner_view of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._manager_of_owner_view = manager_of_owner_view

    @property
    def owner_edit(self):
        """Gets the owner_edit of this BusinessObjectPermission.  # noqa: E501


        :return: The owner_edit of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._owner_edit

    @owner_edit.setter
    def owner_edit(self, owner_edit):
        """Sets the owner_edit of this BusinessObjectPermission.


        :param owner_edit: The owner_edit of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._owner_edit = owner_edit

    @property
    def owner_view(self):
        """Gets the owner_view of this BusinessObjectPermission.  # noqa: E501


        :return: The owner_view of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._owner_view

    @owner_view.setter
    def owner_view(self, owner_view):
        """Sets the owner_view of this BusinessObjectPermission.


        :param owner_view: The owner_view of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._owner_view = owner_view

    @property
    def team_edit(self):
        """Gets the team_edit of this BusinessObjectPermission.  # noqa: E501


        :return: The team_edit of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._team_edit

    @team_edit.setter
    def team_edit(self, team_edit):
        """Sets the team_edit of this BusinessObjectPermission.


        :param team_edit: The team_edit of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._team_edit = team_edit

    @property
    def team_manager_of_owner_edit(self):
        """Gets the team_manager_of_owner_edit of this BusinessObjectPermission.  # noqa: E501


        :return: The team_manager_of_owner_edit of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._team_manager_of_owner_edit

    @team_manager_of_owner_edit.setter
    def team_manager_of_owner_edit(self, team_manager_of_owner_edit):
        """Sets the team_manager_of_owner_edit of this BusinessObjectPermission.


        :param team_manager_of_owner_edit: The team_manager_of_owner_edit of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._team_manager_of_owner_edit = team_manager_of_owner_edit

    @property
    def team_manager_of_owner_view(self):
        """Gets the team_manager_of_owner_view of this BusinessObjectPermission.  # noqa: E501


        :return: The team_manager_of_owner_view of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._team_manager_of_owner_view

    @team_manager_of_owner_view.setter
    def team_manager_of_owner_view(self, team_manager_of_owner_view):
        """Sets the team_manager_of_owner_view of this BusinessObjectPermission.


        :param team_manager_of_owner_view: The team_manager_of_owner_view of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._team_manager_of_owner_view = team_manager_of_owner_view

    @property
    def team_view(self):
        """Gets the team_view of this BusinessObjectPermission.  # noqa: E501


        :return: The team_view of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._team_view

    @team_view.setter
    def team_view(self, team_view):
        """Sets the team_view of this BusinessObjectPermission.


        :param team_view: The team_view of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._team_view = team_view

    @property
    def view(self):
        """Gets the view of this BusinessObjectPermission.  # noqa: E501


        :return: The view of this BusinessObjectPermission.  # noqa: E501
        :rtype: bool
        """
        return self._view

    @view.setter
    def view(self, view):
        """Sets the view of this BusinessObjectPermission.


        :param view: The view of this BusinessObjectPermission.  # noqa: E501
        :type: bool
        """

        self._view = view

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectPermission):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BusinessObjectPermission):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class RelatedSaveResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'parent_bus_ob_id': 'str',
        'parent_bus_ob_public_id': 'str',
        'parent_bus_ob_rec_id': 'str',
        'relationship_id': 'str',
        'bus_ob_public_id': 'str',
        'bus_ob_rec_id': 'str',
        'cache_key': 'str',
        'field_validation_errors': 'list[FieldValidationError]',
        'notification_triggers': 'list[NotificationTrigger]',
        'error_code': 'str',
        'error_message': 'str',
        'has_error': 'bool'
    }

    attribute_map = {
        'parent_bus_ob_id': 'parentBusObId',
        'parent_bus_ob_public_id': 'parentBusObPublicId',
        'parent_bus_ob_rec_id': 'parentBusObRecId',
        'relationship_id': 'relationshipId',
        'bus_ob_public_id': 'busObPublicId',
        'bus_ob_rec_id': 'busObRecId',
        'cache_key': 'cacheKey',
        'field_validation_errors': 'fieldValidationErrors',
        'notification_triggers': 'notificationTriggers',
        'error_code': 'errorCode',
        'error_message': 'errorMessage',
        'has_error': 'hasError'
    }

    def __init__(self, parent_bus_ob_id=None, parent_bus_ob_public_id=None, parent_bus_ob_rec_id=None, relationship_id=None, bus_ob_public_id=None, bus_ob_rec_id=None, cache_key=None, field_validation_errors=None, notification_triggers=None, error_code=None, error_message=None, has_error=None, local_vars_configuration=None):  # noqa: E501
        """RelatedSaveResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._parent_bus_ob_id = None
        self._parent_bus_ob_public_id = None
        self._parent_bus_ob_rec_id = None
        self._relationship_id = None
        self._bus_ob_public_id = None
        self._bus_ob_rec_id = None
        self._cache_key = None
        self._field_validation_errors = None
        self._notification_triggers = None
        self._error_code = None
        self._error_message = None
        self._has_error = None
        self.discriminator = None

        if parent_bus_ob_id is not None:
            self.parent_bus_ob_id = parent_bus_ob_id
        if parent_bus_ob_public_id is not None:
            self.parent_bus_ob_public_id = parent_bus_ob_public_id
        if parent_bus_ob_rec_id is not None:
            self.parent_bus_ob_rec_id = parent_bus_ob_rec_id
        if relationship_id is not None:
            self.relationship_id = relationship_id
        if bus_ob_public_id is not None:
            self.bus_ob_public_id = bus_ob_public_id
        if bus_ob_rec_id is not None:
            self.bus_ob_rec_id = bus_ob_rec_id
        if cache_key is not None:
            self.cache_key = cache_key
        if field_validation_errors is not None:
            self.field_validation_errors = field_validation_errors
        if notification_triggers is not None:
            self.notification_triggers = notification_triggers
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message
        if has_error is not None:
            self.has_error = has_error

    @property
    def parent_bus_ob_id(self):
        """Gets the parent_bus_ob_id of this RelatedSaveResponse.  # noqa: E501


        :return: The parent_bus_ob_id of this RelatedSaveResponse.  # noqa: E501
        :rtype: str
        """
        return self._parent_bus_ob_id

    @parent_bus_ob_id.setter
    def parent_bus_ob_id(self, parent_bus_ob_id):
        """Sets the parent_bus_ob_id of this RelatedSaveResponse.


        :param parent_bus_ob_id: The parent_bus_ob_id of this RelatedSaveResponse.  # noqa: E501
        :type: str
        """

        self._parent_bus_ob_id = parent_bus_ob_id

    @property
    def parent_bus_ob_public_id(self):
        """Gets the parent_bus_ob_public_id of this RelatedSaveResponse.  # noqa: E501


        :return: The parent_bus_ob_public_id of this RelatedSaveResponse.  # noqa: E501
        :rtype: str
        """
        return self._parent_bus_ob_public_id

    @parent_bus_ob_public_id.setter
    def parent_bus_ob_public_id(self, parent_bus_ob_public_id):
        """Sets the parent_bus_ob_public_id of this RelatedSaveResponse.


        :param parent_bus_ob_public_id: The parent_bus_ob_public_id of this RelatedSaveResponse.  # noqa: E501
        :type: str
        """

        self._parent_bus_ob_public_id = parent_bus_ob_public_id

    @property
    def parent_bus_ob_rec_id(self):
        """Gets the parent_bus_ob_rec_id of this RelatedSaveResponse.  # noqa: E501


        :return: The parent_bus_ob_rec_id of this RelatedSaveResponse.  # noqa: E501
        :rtype: str
        """
        return self._parent_bus_ob_rec_id

    @parent_bus_ob_rec_id.setter
    def parent_bus_ob_rec_id(self, parent_bus_ob_rec_id):
        """Sets the parent_bus_ob_rec_id of this RelatedSaveResponse.


        :param parent_bus_ob_rec_id: The parent_bus_ob_rec_id of this RelatedSaveResponse.  # noqa: E501
        :type: str
        """

        self._parent_bus_ob_rec_id = parent_bus_ob_rec_id

    @property
    def relationship_id(self):
        """Gets the relationship_id of this RelatedSaveResponse.  # noqa: E501


        :return: The relationship_id of this RelatedSaveResponse.  # noqa: E501
        :rtype: str
        """
        return self._relationship_id

    @relationship_id.setter
    def relationship_id(self, relationship_id):
        """Sets the relationship_id of this RelatedSaveResponse.


        :param relationship_id: The relationship_id of this RelatedSaveResponse.  # noqa: E501
        :type: str
        """

        self._relationship_id = relationship_id

    @property
    def bus_ob_public_id(self):
        """Gets the bus_ob_public_id of this RelatedSaveResponse.  # noqa: E501


        :return: The bus_ob_public_id of this RelatedSaveResponse.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_public_id

    @bus_ob_public_id.setter
    def bus_ob_public_id(self, bus_ob_public_id):
        """Sets the bus_ob_public_id of this RelatedSaveResponse.


        :param bus_ob_public_id: The bus_ob_public_id of this RelatedSaveResponse.  # noqa: E501
        :type: str
        """

        self._bus_ob_public_id = bus_ob_public_id

    @property
    def bus_ob_rec_id(self):
        """Gets the bus_ob_rec_id of this RelatedSaveResponse.  # noqa: E501


        :return: The bus_ob_rec_id of this RelatedSaveResponse.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_rec_id

    @bus_ob_rec_id.setter
    def bus_ob_rec_id(self, bus_ob_rec_id):
        """Sets the bus_ob_rec_id of this RelatedSaveResponse.


        :param bus_ob_rec_id: The bus_ob_rec_id of this RelatedSaveResponse.  # noqa: E501
        :type: str
        """

        self._bus_ob_rec_id = bus_ob_rec_id

    @property
    def cache_key(self):
        """Gets the cache_key of this RelatedSaveResponse.  # noqa: E501


        :return: The cache_key of this RelatedSaveResponse.  # noqa: E501
        :rtype: str
        """
        return self._cache_key

    @cache_key.setter
    def cache_key(self, cache_key):
        """Sets the cache_key of this RelatedSaveResponse.


        :param cache_key: The cache_key of this RelatedSaveResponse.  # noqa: E501
        :type: str
        """

        self._cache_key = cache_key

    @property
    def field_validation_errors(self):
        """Gets the field_validation_errors of this RelatedSaveResponse.  # noqa: E501


        :return: The field_validation_errors of this RelatedSaveResponse.  # noqa: E501
        :rtype: list[FieldValidationError]
        """
        return self._field_validation_errors

    @field_validation_errors.setter
    def field_validation_errors(self, field_validation_errors):
        """Sets the field_validation_errors of this RelatedSaveResponse.


        :param field_validation_errors: The field_validation_errors of this RelatedSaveResponse.  # noqa: E501
        :type: list[FieldValidationError]
        """

        self._field_validation_errors = field_validation_errors

    @property
    def notification_triggers(self):
        """Gets the notification_triggers of this RelatedSaveResponse.  # noqa: E501


        :return: The notification_triggers of this RelatedSaveResponse.  # noqa: E501
        :rtype: list[NotificationTrigger]
        """
        return self._notification_triggers

    @notification_triggers.setter
    def notification_triggers(self, notification_triggers):
        """Sets the notification_triggers of this RelatedSaveResponse.


        :param notification_triggers: The notification_triggers of this RelatedSaveResponse.  # noqa: E501
        :type: list[NotificationTrigger]
        """

        self._notification_triggers = notification_triggers

    @property
    def error_code(self):
        """Gets the error_code of this RelatedSaveResponse.  # noqa: E501


        :return: The error_code of this RelatedSaveResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this RelatedSaveResponse.


        :param error_code: The error_code of this RelatedSaveResponse.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this RelatedSaveResponse.  # noqa: E501


        :return: The error_message of this RelatedSaveResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this RelatedSaveResponse.


        :param error_message: The error_message of this RelatedSaveResponse.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def has_error(self):
        """Gets the has_error of this RelatedSaveResponse.  # noqa: E501


        :return: The has_error of this RelatedSaveResponse.  # noqa: E501
        :rtype: bool
        """
        return self._has_error

    @has_error.setter
    def has_error(self, has_error):
        """Sets the has_error of this RelatedSaveResponse.


        :param has_error: The has_error of this RelatedSaveResponse.  # noqa: E501
        :type: bool
        """

        self._has_error = has_error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RelatedSaveResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RelatedSaveResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class Field(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'caption': 'str',
        'currency_culture': 'str',
        'currency_symbol': 'str',
        'decimal_digits': 'int',
        'default_sort_order_ascending': 'bool',
        'display_name': 'str',
        'field_name': 'str',
        'full_field_id': 'str',
        'has_default_sort_field': 'bool',
        'field_id': 'str',
        'is_binary': 'bool',
        'is_currency': 'bool',
        'is_date_time': 'bool',
        'is_filter_allowed': 'bool',
        'is_logical': 'bool',
        'is_number': 'bool',
        'is_short_date': 'bool',
        'is_short_time': 'bool',
        'is_visible': 'bool',
        'sortable': 'bool',
        'sort_order': 'str',
        'storage_name': 'str',
        'whole_digits': 'int'
    }

    attribute_map = {
        'caption': 'caption',
        'currency_culture': 'currencyCulture',
        'currency_symbol': 'currencySymbol',
        'decimal_digits': 'decimalDigits',
        'default_sort_order_ascending': 'defaultSortOrderAscending',
        'display_name': 'displayName',
        'field_name': 'fieldName',
        'full_field_id': 'fullFieldId',
        'has_default_sort_field': 'hasDefaultSortField',
        'field_id': 'fieldId',
        'is_binary': 'isBinary',
        'is_currency': 'isCurrency',
        'is_date_time': 'isDateTime',
        'is_filter_allowed': 'isFilterAllowed',
        'is_logical': 'isLogical',
        'is_number': 'isNumber',
        'is_short_date': 'isShortDate',
        'is_short_time': 'isShortTime',
        'is_visible': 'isVisible',
        'sortable': 'sortable',
        'sort_order': 'sortOrder',
        'storage_name': 'storageName',
        'whole_digits': 'wholeDigits'
    }

    def __init__(self, caption=None, currency_culture=None, currency_symbol=None, decimal_digits=None, default_sort_order_ascending=None, display_name=None, field_name=None, full_field_id=None, has_default_sort_field=None, field_id=None, is_binary=None, is_currency=None, is_date_time=None, is_filter_allowed=None, is_logical=None, is_number=None, is_short_date=None, is_short_time=None, is_visible=None, sortable=None, sort_order=None, storage_name=None, whole_digits=None, local_vars_configuration=None):  # noqa: E501
        """Field - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._caption = None
        self._currency_culture = None
        self._currency_symbol = None
        self._decimal_digits = None
        self._default_sort_order_ascending = None
        self._display_name = None
        self._field_name = None
        self._full_field_id = None
        self._has_default_sort_field = None
        self._field_id = None
        self._is_binary = None
        self._is_currency = None
        self._is_date_time = None
        self._is_filter_allowed = None
        self._is_logical = None
        self._is_number = None
        self._is_short_date = None
        self._is_short_time = None
        self._is_visible = None
        self._sortable = None
        self._sort_order = None
        self._storage_name = None
        self._whole_digits = None
        self.discriminator = None

        if caption is not None:
            self.caption = caption
        if currency_culture is not None:
            self.currency_culture = currency_culture
        if currency_symbol is not None:
            self.currency_symbol = currency_symbol
        if decimal_digits is not None:
            self.decimal_digits = decimal_digits
        if default_sort_order_ascending is not None:
            self.default_sort_order_ascending = default_sort_order_ascending
        if display_name is not None:
            self.display_name = display_name
        if field_name is not None:
            self.field_name = field_name
        if full_field_id is not None:
            self.full_field_id = full_field_id
        if has_default_sort_field is not None:
            self.has_default_sort_field = has_default_sort_field
        if field_id is not None:
            self.field_id = field_id
        if is_binary is not None:
            self.is_binary = is_binary
        if is_currency is not None:
            self.is_currency = is_currency
        if is_date_time is not None:
            self.is_date_time = is_date_time
        if is_filter_allowed is not None:
            self.is_filter_allowed = is_filter_allowed
        if is_logical is not None:
            self.is_logical = is_logical
        if is_number is not None:
            self.is_number = is_number
        if is_short_date is not None:
            self.is_short_date = is_short_date
        if is_short_time is not None:
            self.is_short_time = is_short_time
        if is_visible is not None:
            self.is_visible = is_visible
        if sortable is not None:
            self.sortable = sortable
        if sort_order is not None:
            self.sort_order = sort_order
        if storage_name is not None:
            self.storage_name = storage_name
        if whole_digits is not None:
            self.whole_digits = whole_digits

    @property
    def caption(self):
        """Gets the caption of this Field.  # noqa: E501


        :return: The caption of this Field.  # noqa: E501
        :rtype: str
        """
        return self._caption

    @caption.setter
    def caption(self, caption):
        """Sets the caption of this Field.


        :param caption: The caption of this Field.  # noqa: E501
        :type: str
        """

        self._caption = caption

    @property
    def currency_culture(self):
        """Gets the currency_culture of this Field.  # noqa: E501


        :return: The currency_culture of this Field.  # noqa: E501
        :rtype: str
        """
        return self._currency_culture

    @currency_culture.setter
    def currency_culture(self, currency_culture):
        """Sets the currency_culture of this Field.


        :param currency_culture: The currency_culture of this Field.  # noqa: E501
        :type: str
        """

        self._currency_culture = currency_culture

    @property
    def currency_symbol(self):
        """Gets the currency_symbol of this Field.  # noqa: E501


        :return: The currency_symbol of this Field.  # noqa: E501
        :rtype: str
        """
        return self._currency_symbol

    @currency_symbol.setter
    def currency_symbol(self, currency_symbol):
        """Sets the currency_symbol of this Field.


        :param currency_symbol: The currency_symbol of this Field.  # noqa: E501
        :type: str
        """

        self._currency_symbol = currency_symbol

    @property
    def decimal_digits(self):
        """Gets the decimal_digits of this Field.  # noqa: E501


        :return: The decimal_digits of this Field.  # noqa: E501
        :rtype: int
        """
        return self._decimal_digits

    @decimal_digits.setter
    def decimal_digits(self, decimal_digits):
        """Sets the decimal_digits of this Field.


        :param decimal_digits: The decimal_digits of this Field.  # noqa: E501
        :type: int
        """

        self._decimal_digits = decimal_digits

    @property
    def default_sort_order_ascending(self):
        """Gets the default_sort_order_ascending of this Field.  # noqa: E501


        :return: The default_sort_order_ascending of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._default_sort_order_ascending

    @default_sort_order_ascending.setter
    def default_sort_order_ascending(self, default_sort_order_ascending):
        """Sets the default_sort_order_ascending of this Field.


        :param default_sort_order_ascending: The default_sort_order_ascending of this Field.  # noqa: E501
        :type: bool
        """

        self._default_sort_order_ascending = default_sort_order_ascending

    @property
    def display_name(self):
        """Gets the display_name of this Field.  # noqa: E501


        :return: The display_name of this Field.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this Field.


        :param display_name: The display_name of this Field.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def field_name(self):
        """Gets the field_name of this Field.  # noqa: E501


        :return: The field_name of this Field.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this Field.


        :param field_name: The field_name of this Field.  # noqa: E501
        :type: str
        """

        self._field_name = field_name

    @property
    def full_field_id(self):
        """Gets the full_field_id of this Field.  # noqa: E501


        :return: The full_field_id of this Field.  # noqa: E501
        :rtype: str
        """
        return self._full_field_id

    @full_field_id.setter
    def full_field_id(self, full_field_id):
        """Sets the full_field_id of this Field.


        :param full_field_id: The full_field_id of this Field.  # noqa: E501
        :type: str
        """

        self._full_field_id = full_field_id

    @property
    def has_default_sort_field(self):
        """Gets the has_default_sort_field of this Field.  # noqa: E501


        :return: The has_default_sort_field of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._has_default_sort_field

    @has_default_sort_field.setter
    def has_default_sort_field(self, has_default_sort_field):
        """Sets the has_default_sort_field of this Field.


        :param has_default_sort_field: The has_default_sort_field of this Field.  # noqa: E501
        :type: bool
        """

        self._has_default_sort_field = has_default_sort_field

    @property
    def field_id(self):
        """Gets the field_id of this Field.  # noqa: E501


        :return: The field_id of this Field.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this Field.


        :param field_id: The field_id of this Field.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def is_binary(self):
        """Gets the is_binary of this Field.  # noqa: E501


        :return: The is_binary of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._is_binary

    @is_binary.setter
    def is_binary(self, is_binary):
        """Sets the is_binary of this Field.


        :param is_binary: The is_binary of this Field.  # noqa: E501
        :type: bool
        """

        self._is_binary = is_binary

    @property
    def is_currency(self):
        """Gets the is_currency of this Field.  # noqa: E501


        :return: The is_currency of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._is_currency

    @is_currency.setter
    def is_currency(self, is_currency):
        """Sets the is_currency of this Field.


        :param is_currency: The is_currency of this Field.  # noqa: E501
        :type: bool
        """

        self._is_currency = is_currency

    @property
    def is_date_time(self):
        """Gets the is_date_time of this Field.  # noqa: E501


        :return: The is_date_time of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._is_date_time

    @is_date_time.setter
    def is_date_time(self, is_date_time):
        """Sets the is_date_time of this Field.


        :param is_date_time: The is_date_time of this Field.  # noqa: E501
        :type: bool
        """

        self._is_date_time = is_date_time

    @property
    def is_filter_allowed(self):
        """Gets the is_filter_allowed of this Field.  # noqa: E501


        :return: The is_filter_allowed of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._is_filter_allowed

    @is_filter_allowed.setter
    def is_filter_allowed(self, is_filter_allowed):
        """Sets the is_filter_allowed of this Field.


        :param is_filter_allowed: The is_filter_allowed of this Field.  # noqa: E501
        :type: bool
        """

        self._is_filter_allowed = is_filter_allowed

    @property
    def is_logical(self):
        """Gets the is_logical of this Field.  # noqa: E501


        :return: The is_logical of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._is_logical

    @is_logical.setter
    def is_logical(self, is_logical):
        """Sets the is_logical of this Field.


        :param is_logical: The is_logical of this Field.  # noqa: E501
        :type: bool
        """

        self._is_logical = is_logical

    @property
    def is_number(self):
        """Gets the is_number of this Field.  # noqa: E501


        :return: The is_number of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._is_number

    @is_number.setter
    def is_number(self, is_number):
        """Sets the is_number of this Field.


        :param is_number: The is_number of this Field.  # noqa: E501
        :type: bool
        """

        self._is_number = is_number

    @property
    def is_short_date(self):
        """Gets the is_short_date of this Field.  # noqa: E501


        :return: The is_short_date of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._is_short_date

    @is_short_date.setter
    def is_short_date(self, is_short_date):
        """Sets the is_short_date of this Field.


        :param is_short_date: The is_short_date of this Field.  # noqa: E501
        :type: bool
        """

        self._is_short_date = is_short_date

    @property
    def is_short_time(self):
        """Gets the is_short_time of this Field.  # noqa: E501


        :return: The is_short_time of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._is_short_time

    @is_short_time.setter
    def is_short_time(self, is_short_time):
        """Sets the is_short_time of this Field.


        :param is_short_time: The is_short_time of this Field.  # noqa: E501
        :type: bool
        """

        self._is_short_time = is_short_time

    @property
    def is_visible(self):
        """Gets the is_visible of this Field.  # noqa: E501


        :return: The is_visible of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible

    @is_visible.setter
    def is_visible(self, is_visible):
        """Sets the is_visible of this Field.


        :param is_visible: The is_visible of this Field.  # noqa: E501
        :type: bool
        """

        self._is_visible = is_visible

    @property
    def sortable(self):
        """Gets the sortable of this Field.  # noqa: E501


        :return: The sortable of this Field.  # noqa: E501
        :rtype: bool
        """
        return self._sortable

    @sortable.setter
    def sortable(self, sortable):
        """Sets the sortable of this Field.


        :param sortable: The sortable of this Field.  # noqa: E501
        :type: bool
        """

        self._sortable = sortable

    @property
    def sort_order(self):
        """Gets the sort_order of this Field.  # noqa: E501


        :return: The sort_order of this Field.  # noqa: E501
        :rtype: str
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this Field.


        :param sort_order: The sort_order of this Field.  # noqa: E501
        :type: str
        """

        self._sort_order = sort_order

    @property
    def storage_name(self):
        """Gets the storage_name of this Field.  # noqa: E501


        :return: The storage_name of this Field.  # noqa: E501
        :rtype: str
        """
        return self._storage_name

    @storage_name.setter
    def storage_name(self, storage_name):
        """Sets the storage_name of this Field.


        :param storage_name: The storage_name of this Field.  # noqa: E501
        :type: str
        """

        self._storage_name = storage_name

    @property
    def whole_digits(self):
        """Gets the whole_digits of this Field.  # noqa: E501


        :return: The whole_digits of this Field.  # noqa: E501
        :rtype: int
        """
        return self._whole_digits

    @whole_digits.setter
    def whole_digits(self, whole_digits):
        """Sets the whole_digits of this Field.


        :param whole_digits: The whole_digits of this Field.  # noqa: E501
        :type: int
        """

        self._whole_digits = whole_digits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Field):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Field):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pycherwell.api_client import ApiClient
from pycherwell.exceptions import (
    ApiTypeError,
    ApiValueError
)


class TeamsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def teams_add_user_to_team_by_batch_v1(self, add_user_to_team_by_batch_request, **kwargs):  # noqa: E501
        """Add users to a team by batch  # noqa: E501

        Operation to add users to a Team by batch. To get internal IDs for users, use “Get User Information in a Batch.” To get a Team's internal ID, use \"Get all available Teams.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_add_user_to_team_by_batch_v1(add_user_to_team_by_batch_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddUserToTeamByBatchRequest add_user_to_team_by_batch_request: Request object to specify a list of add user to team request objects. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AddUserToTeamByBatchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_add_user_to_team_by_batch_v1_with_http_info(add_user_to_team_by_batch_request, **kwargs)  # noqa: E501

    def teams_add_user_to_team_by_batch_v1_with_http_info(self, add_user_to_team_by_batch_request, **kwargs):  # noqa: E501
        """Add users to a team by batch  # noqa: E501

        Operation to add users to a Team by batch. To get internal IDs for users, use “Get User Information in a Batch.” To get a Team's internal ID, use \"Get all available Teams.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_add_user_to_team_by_batch_v1_with_http_info(add_user_to_team_by_batch_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddUserToTeamByBatchRequest add_user_to_team_by_batch_request: Request object to specify a list of add user to team request objects. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AddUserToTeamByBatchResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['add_user_to_team_by_batch_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_add_user_to_team_by_batch_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'add_user_to_team_by_batch_request' is set
        if self.api_client.client_side_validation and ('add_user_to_team_by_batch_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['add_user_to_team_by_batch_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `add_user_to_team_by_batch_request` when calling `teams_add_user_to_team_by_batch_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_user_to_team_by_batch_request' in local_var_params:
            body_params = local_var_params['add_user_to_team_by_batch_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/addusertoteambybatch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AddUserToTeamByBatchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_add_user_to_team_v1(self, add_user_to_team_request, **kwargs):  # noqa: E501
        """Add a user to a team  # noqa: E501

        Operation to add a user to a Team. To get the user's internal ID, use \"Get a user by login ID\" or \"Get a user by public ID.\" To get a Team's internal ID, use \"Get all available Teams.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_add_user_to_team_v1(add_user_to_team_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddUserToTeamRequest add_user_to_team_request: Request object to specify user and team values. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_add_user_to_team_v1_with_http_info(add_user_to_team_request, **kwargs)  # noqa: E501

    def teams_add_user_to_team_v1_with_http_info(self, add_user_to_team_request, **kwargs):  # noqa: E501
        """Add a user to a team  # noqa: E501

        Operation to add a user to a Team. To get the user's internal ID, use \"Get a user by login ID\" or \"Get a user by public ID.\" To get a Team's internal ID, use \"Get all available Teams.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_add_user_to_team_v1_with_http_info(add_user_to_team_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddUserToTeamRequest add_user_to_team_request: Request object to specify user and team values. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['add_user_to_team_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_add_user_to_team_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'add_user_to_team_request' is set
        if self.api_client.client_side_validation and ('add_user_to_team_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['add_user_to_team_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `add_user_to_team_request` when calling `teams_add_user_to_team_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_user_to_team_request' in local_var_params:
            body_params = local_var_params['add_user_to_team_request']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/addusertoteam', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_add_user_to_team_v2(self, add_user_to_team_request, **kwargs):  # noqa: E501
        """Add a user to a team  # noqa: E501

        Operation to add a user to a Team. To get the user's internal ID, use \"Get a user by login ID\" or \"Get a user by public ID.\" To get a Team's internal ID, use \"Get all available Teams.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_add_user_to_team_v2(add_user_to_team_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddUserToTeamRequest add_user_to_team_request: Request object to specify user and team values. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AddUserToTeamResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_add_user_to_team_v2_with_http_info(add_user_to_team_request, **kwargs)  # noqa: E501

    def teams_add_user_to_team_v2_with_http_info(self, add_user_to_team_request, **kwargs):  # noqa: E501
        """Add a user to a team  # noqa: E501

        Operation to add a user to a Team. To get the user's internal ID, use \"Get a user by login ID\" or \"Get a user by public ID.\" To get a Team's internal ID, use \"Get all available Teams.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_add_user_to_team_v2_with_http_info(add_user_to_team_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddUserToTeamRequest add_user_to_team_request: Request object to specify user and team values. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AddUserToTeamResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['add_user_to_team_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_add_user_to_team_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'add_user_to_team_request' is set
        if self.api_client.client_side_validation and ('add_user_to_team_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['add_user_to_team_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `add_user_to_team_request` when calling `teams_add_user_to_team_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_user_to_team_request' in local_var_params:
            body_params = local_var_params['add_user_to_team_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/addusertoteam', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AddUserToTeamResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_delete_team_v1(self, teamid, **kwargs):  # noqa: E501
        """Delete a Team  # noqa: E501

        Operation to delete a Team by Team ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_delete_team_v1(teamid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str teamid: Specify the Team ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_delete_team_v1_with_http_info(teamid, **kwargs)  # noqa: E501

    def teams_delete_team_v1_with_http_info(self, teamid, **kwargs):  # noqa: E501
        """Delete a Team  # noqa: E501

        Operation to delete a Team by Team ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_delete_team_v1_with_http_info(teamid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str teamid: Specify the Team ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['teamid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_delete_team_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'teamid' is set
        if self.api_client.client_side_validation and ('teamid' not in local_var_params or  # noqa: E501
                                                        local_var_params['teamid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `teamid` when calling `teams_delete_team_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'teamid' in local_var_params:
            path_params['teamid'] = local_var_params['teamid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/deleteteam/{teamid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_get_team_v1(self, teamid, **kwargs):  # noqa: E501
        """Get a team by its TeamId  # noqa: E501

        Operation to get Team Info for a  single Team using its Team ID. To get a Team's internal ID, use \"Get all available Teams.\" Note that TeamType has two possible values, where TeamType = 0 for User (CSM Users), or TeamType = 1 for Workgroup (CSM Customers).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_team_v1(teamid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str teamid: The Team ID of the Team to get. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TeamResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_get_team_v1_with_http_info(teamid, **kwargs)  # noqa: E501

    def teams_get_team_v1_with_http_info(self, teamid, **kwargs):  # noqa: E501
        """Get a team by its TeamId  # noqa: E501

        Operation to get Team Info for a  single Team using its Team ID. To get a Team's internal ID, use \"Get all available Teams.\" Note that TeamType has two possible values, where TeamType = 0 for User (CSM Users), or TeamType = 1 for Workgroup (CSM Customers).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_team_v1_with_http_info(teamid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str teamid: The Team ID of the Team to get. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TeamResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['teamid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_get_team_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'teamid' is set
        if self.api_client.client_side_validation and ('teamid' not in local_var_params or  # noqa: E501
                                                        local_var_params['teamid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `teamid` when calling `teams_get_team_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'teamid' in local_var_params:
            path_params['teamid'] = local_var_params['teamid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getteam/{teamid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_get_teams_v1(self, **kwargs):  # noqa: E501
        """Get all available Teams  # noqa: E501

        Operation to get IDs and names for all available Teams.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_teams_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TeamsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_get_teams_v1_with_http_info(**kwargs)  # noqa: E501

    def teams_get_teams_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Get all available Teams  # noqa: E501

        Operation to get IDs and names for all available Teams.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_teams_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TeamsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_get_teams_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getteams', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_get_teams_v2(self, **kwargs):  # noqa: E501
        """Get all available Teams  # noqa: E501

        Operation to get IDs and names for all available Teams.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_teams_v2(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TeamsV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_get_teams_v2_with_http_info(**kwargs)  # noqa: E501

    def teams_get_teams_v2_with_http_info(self, **kwargs):  # noqa: E501
        """Get all available Teams  # noqa: E501

        Operation to get IDs and names for all available Teams.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_teams_v2_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TeamsV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_get_teams_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getteams', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamsV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_get_users_teams_v1(self, user_record_id, **kwargs):  # noqa: E501
        """Get Team assignments for a user  # noqa: E501

        Operation to get Team assignments for a user. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_users_teams_v1(user_record_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_record_id: Specify the user record ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TeamsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_get_users_teams_v1_with_http_info(user_record_id, **kwargs)  # noqa: E501

    def teams_get_users_teams_v1_with_http_info(self, user_record_id, **kwargs):  # noqa: E501
        """Get Team assignments for a user  # noqa: E501

        Operation to get Team assignments for a user. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_users_teams_v1_with_http_info(user_record_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_record_id: Specify the user record ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TeamsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_record_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_get_users_teams_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_record_id' is set
        if self.api_client.client_side_validation and ('user_record_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_record_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_record_id` when calling `teams_get_users_teams_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_record_id' in local_var_params:
            path_params['userRecordId'] = local_var_params['user_record_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getusersteams/userrecordid/{userRecordId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_get_users_teams_v2(self, user_record_id, **kwargs):  # noqa: E501
        """Get Team assignments for a user  # noqa: E501

        Operation to get Team assignments for a user. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_users_teams_v2(user_record_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_record_id: Specify the user record ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TeamsV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_get_users_teams_v2_with_http_info(user_record_id, **kwargs)  # noqa: E501

    def teams_get_users_teams_v2_with_http_info(self, user_record_id, **kwargs):  # noqa: E501
        """Get Team assignments for a user  # noqa: E501

        Operation to get Team assignments for a user. To get record IDs, use \"Get a user by login ID\" or \"Get a user by public id.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_users_teams_v2_with_http_info(user_record_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_record_id: Specify the user record ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TeamsV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_record_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_get_users_teams_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_record_id' is set
        if self.api_client.client_side_validation and ('user_record_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_record_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_record_id` when calling `teams_get_users_teams_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_record_id' in local_var_params:
            path_params['userRecordId'] = local_var_params['user_record_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getusersteams/userrecordid/{userRecordId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamsV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_get_workgroups_v1(self, **kwargs):  # noqa: E501
        """Get all available Workgroups  # noqa: E501

        Operation to get IDs and names for all available Workgroups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_workgroups_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TeamsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_get_workgroups_v1_with_http_info(**kwargs)  # noqa: E501

    def teams_get_workgroups_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Get all available Workgroups  # noqa: E501

        Operation to get IDs and names for all available Workgroups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_workgroups_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TeamsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_get_workgroups_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getworkgroups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_get_workgroups_v2(self, **kwargs):  # noqa: E501
        """Get all available Workgroups  # noqa: E501

        Operation to get IDs and names for all available Workgroups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_workgroups_v2(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TeamsV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_get_workgroups_v2_with_http_info(**kwargs)  # noqa: E501

    def teams_get_workgroups_v2_with_http_info(self, **kwargs):  # noqa: E501
        """Get all available Workgroups  # noqa: E501

        Operation to get IDs and names for all available Workgroups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_get_workgroups_v2_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TeamsV2Response, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_get_workgroups_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/getworkgroups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamsV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_remove_customer_from_workgroup_v1(self, workgroupid, customerrecordid, **kwargs):  # noqa: E501
        """Remove a customer from a Workgroup  # noqa: E501

        Operation to remove a Customer from a Workgroup.  To remove, specify the Workgroup ID and the Customer Record ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_remove_customer_from_workgroup_v1(workgroupid, customerrecordid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workgroupid: Specify the Workgroup ID. (required)
        :param str customerrecordid: Specify the Customer record ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RemoveCustomerFromWorkgroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_remove_customer_from_workgroup_v1_with_http_info(workgroupid, customerrecordid, **kwargs)  # noqa: E501

    def teams_remove_customer_from_workgroup_v1_with_http_info(self, workgroupid, customerrecordid, **kwargs):  # noqa: E501
        """Remove a customer from a Workgroup  # noqa: E501

        Operation to remove a Customer from a Workgroup.  To remove, specify the Workgroup ID and the Customer Record ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_remove_customer_from_workgroup_v1_with_http_info(workgroupid, customerrecordid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workgroupid: Specify the Workgroup ID. (required)
        :param str customerrecordid: Specify the Customer record ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RemoveCustomerFromWorkgroupResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['workgroupid', 'customerrecordid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_remove_customer_from_workgroup_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workgroupid' is set
        if self.api_client.client_side_validation and ('workgroupid' not in local_var_params or  # noqa: E501
                                                        local_var_params['workgroupid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workgroupid` when calling `teams_remove_customer_from_workgroup_v1`")  # noqa: E501
        # verify the required parameter 'customerrecordid' is set
        if self.api_client.client_side_validation and ('customerrecordid' not in local_var_params or  # noqa: E501
                                                        local_var_params['customerrecordid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `customerrecordid` when calling `teams_remove_customer_from_workgroup_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workgroupid' in local_var_params:
            path_params['workgroupid'] = local_var_params['workgroupid']  # noqa: E501
        if 'customerrecordid' in local_var_params:
            path_params['customerrecordid'] = local_var_params['customerrecordid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/removecustomerfromworkgroup/workgroupid/{workgroupid}/customerrecordid/{customerrecordid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RemoveCustomerFromWorkgroupResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_remove_user_from_team_v1(self, team_id, userrecordid, **kwargs):  # noqa: E501
        """Operation to remove a User from a Team.  # noqa: E501

        Operation to remove a User from a Team. To get the User's record ID, use \"Get a User by login ID\" or \"Get a User by public ID.\" To get a Team's internal ID, use \"Get all available Teams.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_remove_user_from_team_v1(team_id, userrecordid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str team_id: Specify the internal ID of the Team. (required)
        :param str userrecordid: Specify the record ID of the User to remove. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_remove_user_from_team_v1_with_http_info(team_id, userrecordid, **kwargs)  # noqa: E501

    def teams_remove_user_from_team_v1_with_http_info(self, team_id, userrecordid, **kwargs):  # noqa: E501
        """Operation to remove a User from a Team.  # noqa: E501

        Operation to remove a User from a Team. To get the User's record ID, use \"Get a User by login ID\" or \"Get a User by public ID.\" To get a Team's internal ID, use \"Get all available Teams.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_remove_user_from_team_v1_with_http_info(team_id, userrecordid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str team_id: Specify the internal ID of the Team. (required)
        :param str userrecordid: Specify the record ID of the User to remove. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['team_id', 'userrecordid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_remove_user_from_team_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'team_id' is set
        if self.api_client.client_side_validation and ('team_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['team_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `team_id` when calling `teams_remove_user_from_team_v1`")  # noqa: E501
        # verify the required parameter 'userrecordid' is set
        if self.api_client.client_side_validation and ('userrecordid' not in local_var_params or  # noqa: E501
                                                        local_var_params['userrecordid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `userrecordid` when calling `teams_remove_user_from_team_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_id' in local_var_params:
            path_params['teamId'] = local_var_params['team_id']  # noqa: E501
        if 'userrecordid' in local_var_params:
            path_params['userrecordid'] = local_var_params['userrecordid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/removeuserfromteam/teamid/{teamId}/userrecordid/{userrecordid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_remove_user_from_team_v2(self, team_id, userrecordid, **kwargs):  # noqa: E501
        """Operation to remove a User from a Team.  # noqa: E501

        Operation to remove a User from a Team. To get the User's record ID, use \"Get a User by login ID\" or \"Get a User by public ID.\" To get a Team's internal ID, use \"Get all available Teams.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_remove_user_from_team_v2(team_id, userrecordid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str team_id: Specify the internal ID of the Team. (required)
        :param str userrecordid: Specify the record ID of the User to remove. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RemoveUserFromTeamResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_remove_user_from_team_v2_with_http_info(team_id, userrecordid, **kwargs)  # noqa: E501

    def teams_remove_user_from_team_v2_with_http_info(self, team_id, userrecordid, **kwargs):  # noqa: E501
        """Operation to remove a User from a Team.  # noqa: E501

        Operation to remove a User from a Team. To get the User's record ID, use \"Get a User by login ID\" or \"Get a User by public ID.\" To get a Team's internal ID, use \"Get all available Teams.\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_remove_user_from_team_v2_with_http_info(team_id, userrecordid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str team_id: Specify the internal ID of the Team. (required)
        :param str userrecordid: Specify the record ID of the User to remove. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RemoveUserFromTeamResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['team_id', 'userrecordid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_remove_user_from_team_v2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'team_id' is set
        if self.api_client.client_side_validation and ('team_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['team_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `team_id` when calling `teams_remove_user_from_team_v2`")  # noqa: E501
        # verify the required parameter 'userrecordid' is set
        if self.api_client.client_side_validation and ('userrecordid' not in local_var_params or  # noqa: E501
                                                        local_var_params['userrecordid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `userrecordid` when calling `teams_remove_user_from_team_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_id' in local_var_params:
            path_params['teamId'] = local_var_params['team_id']  # noqa: E501
        if 'userrecordid' in local_var_params:
            path_params['userrecordid'] = local_var_params['userrecordid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V2/removeuserfromteam/teamid/{teamId}/userrecordid/{userrecordid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RemoveUserFromTeamResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_save_team_member_v1(self, save_team_member_request, **kwargs):  # noqa: E501
        """Add or Update a team member  # noqa: E501

        Operation to add or update a Team Member. To add or update, specify User ID, Team ID, and if Team Manager.   Optionally, set the Team as the User's default Team.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_save_team_member_v1(save_team_member_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveTeamMemberRequest save_team_member_request: The request object to add or update a Team Member. User recID specifies the User to add or update. TeamId specifies the Team to update. IsTeamManager specifies whether the User is a Team Manager, and SetAsDefaultTeam specifies whether to set this Team as the User's default team. UserRecId, TeamId, and IsTeamManager are required. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SaveTeamMemberResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_save_team_member_v1_with_http_info(save_team_member_request, **kwargs)  # noqa: E501

    def teams_save_team_member_v1_with_http_info(self, save_team_member_request, **kwargs):  # noqa: E501
        """Add or Update a team member  # noqa: E501

        Operation to add or update a Team Member. To add or update, specify User ID, Team ID, and if Team Manager.   Optionally, set the Team as the User's default Team.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_save_team_member_v1_with_http_info(save_team_member_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveTeamMemberRequest save_team_member_request: The request object to add or update a Team Member. User recID specifies the User to add or update. TeamId specifies the Team to update. IsTeamManager specifies whether the User is a Team Manager, and SetAsDefaultTeam specifies whether to set this Team as the User's default team. UserRecId, TeamId, and IsTeamManager are required. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SaveTeamMemberResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['save_team_member_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_save_team_member_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'save_team_member_request' is set
        if self.api_client.client_side_validation and ('save_team_member_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['save_team_member_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `save_team_member_request` when calling `teams_save_team_member_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'save_team_member_request' in local_var_params:
            body_params = local_var_params['save_team_member_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/saveteammember', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SaveTeamMemberResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_save_team_v1(self, team_save_request, **kwargs):  # noqa: E501
        """Create or update a team  # noqa: E501

        Operation to create or update a Team or Workgroup.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_save_team_v1(team_save_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param TeamSaveRequest team_save_request: Request object to create Teams or Workgroups. To create a Team, use teamType and teamName. To update a team, use teamID. Team type values must be User or CustomerWorkgroup. The teamType cannot be changed for existing Teams or Workgroups. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TeamSaveResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_save_team_v1_with_http_info(team_save_request, **kwargs)  # noqa: E501

    def teams_save_team_v1_with_http_info(self, team_save_request, **kwargs):  # noqa: E501
        """Create or update a team  # noqa: E501

        Operation to create or update a Team or Workgroup.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_save_team_v1_with_http_info(team_save_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param TeamSaveRequest team_save_request: Request object to create Teams or Workgroups. To create a Team, use teamType and teamName. To update a team, use teamID. Team type values must be User or CustomerWorkgroup. The teamType cannot be changed for existing Teams or Workgroups. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TeamSaveResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['team_save_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_save_team_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'team_save_request' is set
        if self.api_client.client_side_validation and ('team_save_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['team_save_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `team_save_request` when calling `teams_save_team_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'team_save_request' in local_var_params:
            body_params = local_var_params['team_save_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/saveteam', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TeamSaveResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def teams_save_workgroup_member_v1(self, save_workgroup_member_request, **kwargs):  # noqa: E501
        """Save the membership status of a Workgroup member.  # noqa: E501

        Operation to add or update a Workgroup Member.  To add or update, specify Customer Record ID, Workgroup ID, and if Workgroup Manager.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_save_workgroup_member_v1(save_workgroup_member_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveWorkgroupMemberRequest save_workgroup_member_request: The request object to add or update a Workgroup Member. CustomerRecordId specifies the Customer to add or update. WorkgroupId specifies the Workgroup to update. CustomerIsWorkgroupManager specifies whether the Customer is a Workgroup Manager. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SaveWorkgroupMemberResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.teams_save_workgroup_member_v1_with_http_info(save_workgroup_member_request, **kwargs)  # noqa: E501

    def teams_save_workgroup_member_v1_with_http_info(self, save_workgroup_member_request, **kwargs):  # noqa: E501
        """Save the membership status of a Workgroup member.  # noqa: E501

        Operation to add or update a Workgroup Member.  To add or update, specify Customer Record ID, Workgroup ID, and if Workgroup Manager.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.teams_save_workgroup_member_v1_with_http_info(save_workgroup_member_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveWorkgroupMemberRequest save_workgroup_member_request: The request object to add or update a Workgroup Member. CustomerRecordId specifies the Customer to add or update. WorkgroupId specifies the Workgroup to update. CustomerIsWorkgroupManager specifies whether the Customer is a Workgroup Manager. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SaveWorkgroupMemberResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['save_workgroup_member_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method teams_save_workgroup_member_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'save_workgroup_member_request' is set
        if self.api_client.client_side_validation and ('save_workgroup_member_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['save_workgroup_member_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `save_workgroup_member_request` when calling `teams_save_workgroup_member_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'save_workgroup_member_request' in local_var_params:
            body_params = local_var_params['save_workgroup_member_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/saveworkgroupmember', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SaveWorkgroupMemberResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
